# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.ads.admanager import gapic_version as package_version

__version__ = package_version.__version__


from google.ads.admanager_v1.services.ad_break_service.client import (
    AdBreakServiceClient,
)
from google.ads.admanager_v1.services.ad_review_center_ad_service.client import (
    AdReviewCenterAdServiceClient,
)
from google.ads.admanager_v1.services.ad_unit_service.client import AdUnitServiceClient
from google.ads.admanager_v1.services.application_service.client import (
    ApplicationServiceClient,
)
from google.ads.admanager_v1.services.audience_segment_service.client import (
    AudienceSegmentServiceClient,
)
from google.ads.admanager_v1.services.bandwidth_group_service.client import (
    BandwidthGroupServiceClient,
)
from google.ads.admanager_v1.services.browser_language_service.client import (
    BrowserLanguageServiceClient,
)
from google.ads.admanager_v1.services.browser_service.client import BrowserServiceClient
from google.ads.admanager_v1.services.cms_metadata_key_service.client import (
    CmsMetadataKeyServiceClient,
)
from google.ads.admanager_v1.services.cms_metadata_value_service.client import (
    CmsMetadataValueServiceClient,
)
from google.ads.admanager_v1.services.company_service.client import CompanyServiceClient
from google.ads.admanager_v1.services.contact_service.client import ContactServiceClient
from google.ads.admanager_v1.services.content_bundle_service.client import (
    ContentBundleServiceClient,
)
from google.ads.admanager_v1.services.content_label_service.client import (
    ContentLabelServiceClient,
)
from google.ads.admanager_v1.services.content_service.client import ContentServiceClient
from google.ads.admanager_v1.services.creative_template_service.client import (
    CreativeTemplateServiceClient,
)
from google.ads.admanager_v1.services.custom_field_service.client import (
    CustomFieldServiceClient,
)
from google.ads.admanager_v1.services.custom_targeting_key_service.client import (
    CustomTargetingKeyServiceClient,
)
from google.ads.admanager_v1.services.custom_targeting_value_service.client import (
    CustomTargetingValueServiceClient,
)
from google.ads.admanager_v1.services.device_capability_service.client import (
    DeviceCapabilityServiceClient,
)
from google.ads.admanager_v1.services.device_category_service.client import (
    DeviceCategoryServiceClient,
)
from google.ads.admanager_v1.services.device_manufacturer_service.client import (
    DeviceManufacturerServiceClient,
)
from google.ads.admanager_v1.services.entity_signals_mapping_service.client import (
    EntitySignalsMappingServiceClient,
)
from google.ads.admanager_v1.services.geo_target_service.client import (
    GeoTargetServiceClient,
)
from google.ads.admanager_v1.services.line_item_service.client import (
    LineItemServiceClient,
)
from google.ads.admanager_v1.services.mobile_carrier_service.client import (
    MobileCarrierServiceClient,
)
from google.ads.admanager_v1.services.mobile_device_service.client import (
    MobileDeviceServiceClient,
)
from google.ads.admanager_v1.services.mobile_device_submodel_service.client import (
    MobileDeviceSubmodelServiceClient,
)
from google.ads.admanager_v1.services.network_service.client import NetworkServiceClient
from google.ads.admanager_v1.services.operating_system_service.client import (
    OperatingSystemServiceClient,
)
from google.ads.admanager_v1.services.operating_system_version_service.client import (
    OperatingSystemVersionServiceClient,
)
from google.ads.admanager_v1.services.order_service.client import OrderServiceClient
from google.ads.admanager_v1.services.placement_service.client import (
    PlacementServiceClient,
)
from google.ads.admanager_v1.services.private_auction_deal_service.client import (
    PrivateAuctionDealServiceClient,
)
from google.ads.admanager_v1.services.private_auction_service.client import (
    PrivateAuctionServiceClient,
)
from google.ads.admanager_v1.services.programmatic_buyer_service.client import (
    ProgrammaticBuyerServiceClient,
)
from google.ads.admanager_v1.services.report_service.client import ReportServiceClient
from google.ads.admanager_v1.services.role_service.client import RoleServiceClient
from google.ads.admanager_v1.services.site_service.client import SiteServiceClient
from google.ads.admanager_v1.services.taxonomy_category_service.client import (
    TaxonomyCategoryServiceClient,
)
from google.ads.admanager_v1.services.team_service.client import TeamServiceClient
from google.ads.admanager_v1.services.user_service.client import UserServiceClient
from google.ads.admanager_v1.types.ad_break_messages import AdBreak
from google.ads.admanager_v1.types.ad_break_service import (
    CreateAdBreakRequest,
    DeleteAdBreakRequest,
    GetAdBreakRequest,
    ListAdBreaksRequest,
    ListAdBreaksResponse,
    UpdateAdBreakRequest,
)
from google.ads.admanager_v1.types.ad_review_center_ad_enums import (
    AdReviewCenterAdStatusEnum,
)
from google.ads.admanager_v1.types.ad_review_center_ad_messages import AdReviewCenterAd
from google.ads.admanager_v1.types.ad_review_center_ad_service import (
    BatchAdReviewCenterAdsOperationMetadata,
    BatchAllowAdReviewCenterAdsRequest,
    BatchAllowAdReviewCenterAdsResponse,
    BatchBlockAdReviewCenterAdsRequest,
    BatchBlockAdReviewCenterAdsResponse,
    SearchAdReviewCenterAdsRequest,
    SearchAdReviewCenterAdsResponse,
)
from google.ads.admanager_v1.types.ad_unit_enums import (
    AdUnitStatusEnum,
    SmartSizeModeEnum,
    TargetWindowEnum,
)
from google.ads.admanager_v1.types.ad_unit_messages import (
    AdUnit,
    AdUnitParent,
    AdUnitSize,
    LabelFrequencyCap,
)
from google.ads.admanager_v1.types.ad_unit_service import (
    BatchActivateAdUnitsRequest,
    BatchActivateAdUnitsResponse,
    BatchArchiveAdUnitsRequest,
    BatchArchiveAdUnitsResponse,
    BatchCreateAdUnitsRequest,
    BatchCreateAdUnitsResponse,
    BatchDeactivateAdUnitsRequest,
    BatchDeactivateAdUnitsResponse,
    BatchUpdateAdUnitsRequest,
    BatchUpdateAdUnitsResponse,
    CreateAdUnitRequest,
    GetAdUnitRequest,
    ListAdUnitSizesRequest,
    ListAdUnitSizesResponse,
    ListAdUnitsRequest,
    ListAdUnitsResponse,
    UpdateAdUnitRequest,
)
from google.ads.admanager_v1.types.admanager_error import AdManagerError
from google.ads.admanager_v1.types.application_messages import Application
from google.ads.admanager_v1.types.application_service import (
    GetApplicationRequest,
    ListApplicationsRequest,
    ListApplicationsResponse,
)
from google.ads.admanager_v1.types.applied_label import AppliedLabel
from google.ads.admanager_v1.types.audience_segment_messages import AudienceSegment
from google.ads.admanager_v1.types.audience_segment_service import (
    GetAudienceSegmentRequest,
    ListAudienceSegmentsRequest,
    ListAudienceSegmentsResponse,
)
from google.ads.admanager_v1.types.bandwidth_group_messages import BandwidthGroup
from google.ads.admanager_v1.types.bandwidth_group_service import (
    GetBandwidthGroupRequest,
    ListBandwidthGroupsRequest,
    ListBandwidthGroupsResponse,
)
from google.ads.admanager_v1.types.browser_language_messages import BrowserLanguage
from google.ads.admanager_v1.types.browser_language_service import (
    GetBrowserLanguageRequest,
    ListBrowserLanguagesRequest,
    ListBrowserLanguagesResponse,
)
from google.ads.admanager_v1.types.browser_messages import Browser
from google.ads.admanager_v1.types.browser_service import (
    GetBrowserRequest,
    ListBrowsersRequest,
    ListBrowsersResponse,
)
from google.ads.admanager_v1.types.cms_metadata_key_enums import (
    CmsMetadataKeyStatusEnum,
)
from google.ads.admanager_v1.types.cms_metadata_key_messages import CmsMetadataKey
from google.ads.admanager_v1.types.cms_metadata_key_service import (
    GetCmsMetadataKeyRequest,
    ListCmsMetadataKeysRequest,
    ListCmsMetadataKeysResponse,
)
from google.ads.admanager_v1.types.cms_metadata_value_enums import (
    CmsMetadataValueStatusEnum,
)
from google.ads.admanager_v1.types.cms_metadata_value_messages import CmsMetadataValue
from google.ads.admanager_v1.types.cms_metadata_value_service import (
    GetCmsMetadataValueRequest,
    ListCmsMetadataValuesRequest,
    ListCmsMetadataValuesResponse,
)
from google.ads.admanager_v1.types.company_enums import (
    CompanyCreditStatusEnum,
    CompanyTypeEnum,
)
from google.ads.admanager_v1.types.company_messages import Company
from google.ads.admanager_v1.types.company_service import (
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
)
from google.ads.admanager_v1.types.contact_enums import ContactStatusEnum
from google.ads.admanager_v1.types.contact_messages import Contact
from google.ads.admanager_v1.types.contact_service import (
    BatchCreateContactsRequest,
    BatchCreateContactsResponse,
    BatchUpdateContactsRequest,
    BatchUpdateContactsResponse,
    CreateContactRequest,
    GetContactRequest,
    ListContactsRequest,
    ListContactsResponse,
    UpdateContactRequest,
)
from google.ads.admanager_v1.types.content_bundle_messages import ContentBundle
from google.ads.admanager_v1.types.content_bundle_service import (
    GetContentBundleRequest,
    ListContentBundlesRequest,
    ListContentBundlesResponse,
)
from google.ads.admanager_v1.types.content_label_messages import ContentLabel
from google.ads.admanager_v1.types.content_label_service import (
    GetContentLabelRequest,
    ListContentLabelsRequest,
    ListContentLabelsResponse,
)
from google.ads.admanager_v1.types.content_messages import Content
from google.ads.admanager_v1.types.content_service import (
    GetContentRequest,
    ListContentRequest,
    ListContentResponse,
)
from google.ads.admanager_v1.types.creative_template_enums import (
    CreativeTemplateStatusEnum,
    CreativeTemplateTypeEnum,
)
from google.ads.admanager_v1.types.creative_template_messages import (
    CreativeTemplate,
    CreativeTemplateVariable,
)
from google.ads.admanager_v1.types.creative_template_service import (
    GetCreativeTemplateRequest,
    ListCreativeTemplatesRequest,
    ListCreativeTemplatesResponse,
)
from google.ads.admanager_v1.types.creative_template_variable_url_type_enum import (
    CreativeTemplateVariableUrlTypeEnum,
)
from google.ads.admanager_v1.types.custom_field_enums import (
    CustomFieldDataTypeEnum,
    CustomFieldEntityTypeEnum,
    CustomFieldStatusEnum,
    CustomFieldVisibilityEnum,
)
from google.ads.admanager_v1.types.custom_field_messages import (
    CustomField,
    CustomFieldOption,
)
from google.ads.admanager_v1.types.custom_field_service import (
    BatchActivateCustomFieldsRequest,
    BatchActivateCustomFieldsResponse,
    BatchCreateCustomFieldsRequest,
    BatchCreateCustomFieldsResponse,
    BatchDeactivateCustomFieldsRequest,
    BatchDeactivateCustomFieldsResponse,
    BatchUpdateCustomFieldsRequest,
    BatchUpdateCustomFieldsResponse,
    CreateCustomFieldRequest,
    GetCustomFieldRequest,
    ListCustomFieldsRequest,
    ListCustomFieldsResponse,
    UpdateCustomFieldRequest,
)
from google.ads.admanager_v1.types.custom_field_value import CustomFieldValue
from google.ads.admanager_v1.types.custom_targeting_key_enums import (
    CustomTargetingKeyReportableTypeEnum,
    CustomTargetingKeyStatusEnum,
    CustomTargetingKeyTypeEnum,
)
from google.ads.admanager_v1.types.custom_targeting_key_messages import (
    CustomTargetingKey,
)
from google.ads.admanager_v1.types.custom_targeting_key_service import (
    BatchActivateCustomTargetingKeysRequest,
    BatchActivateCustomTargetingKeysResponse,
    BatchCreateCustomTargetingKeysRequest,
    BatchCreateCustomTargetingKeysResponse,
    BatchDeactivateCustomTargetingKeysRequest,
    BatchDeactivateCustomTargetingKeysResponse,
    BatchUpdateCustomTargetingKeysRequest,
    BatchUpdateCustomTargetingKeysResponse,
    CreateCustomTargetingKeyRequest,
    GetCustomTargetingKeyRequest,
    ListCustomTargetingKeysRequest,
    ListCustomTargetingKeysResponse,
    UpdateCustomTargetingKeyRequest,
)
from google.ads.admanager_v1.types.custom_targeting_value_enums import (
    CustomTargetingValueMatchTypeEnum,
    CustomTargetingValueStatusEnum,
)
from google.ads.admanager_v1.types.custom_targeting_value_messages import (
    CustomTargetingValue,
)
from google.ads.admanager_v1.types.custom_targeting_value_service import (
    GetCustomTargetingValueRequest,
    ListCustomTargetingValuesRequest,
    ListCustomTargetingValuesResponse,
)
from google.ads.admanager_v1.types.deal_buyer_permission_type_enum import (
    DealBuyerPermissionTypeEnum,
)
from google.ads.admanager_v1.types.device_capability_messages import DeviceCapability
from google.ads.admanager_v1.types.device_capability_service import (
    GetDeviceCapabilityRequest,
    ListDeviceCapabilitiesRequest,
    ListDeviceCapabilitiesResponse,
)
from google.ads.admanager_v1.types.device_category_messages import DeviceCategory
from google.ads.admanager_v1.types.device_category_service import (
    GetDeviceCategoryRequest,
    ListDeviceCategoriesRequest,
    ListDeviceCategoriesResponse,
)
from google.ads.admanager_v1.types.device_manufacturer_messages import (
    DeviceManufacturer,
)
from google.ads.admanager_v1.types.device_manufacturer_service import (
    GetDeviceManufacturerRequest,
    ListDeviceManufacturersRequest,
    ListDeviceManufacturersResponse,
)
from google.ads.admanager_v1.types.early_ad_break_notification_enums import (
    AdBreakStateEnum,
)
from google.ads.admanager_v1.types.entity_signals_mapping_messages import (
    EntitySignalsMapping,
)
from google.ads.admanager_v1.types.entity_signals_mapping_service import (
    BatchCreateEntitySignalsMappingsRequest,
    BatchCreateEntitySignalsMappingsResponse,
    BatchUpdateEntitySignalsMappingsRequest,
    BatchUpdateEntitySignalsMappingsResponse,
    CreateEntitySignalsMappingRequest,
    GetEntitySignalsMappingRequest,
    ListEntitySignalsMappingsRequest,
    ListEntitySignalsMappingsResponse,
    UpdateEntitySignalsMappingRequest,
)
from google.ads.admanager_v1.types.environment_type_enum import EnvironmentTypeEnum
from google.ads.admanager_v1.types.exchange_syndication_product_enum import (
    ExchangeSyndicationProductEnum,
)
from google.ads.admanager_v1.types.frequency_cap import FrequencyCap
from google.ads.admanager_v1.types.geo_target_messages import GeoTarget
from google.ads.admanager_v1.types.geo_target_service import (
    GetGeoTargetRequest,
    ListGeoTargetsRequest,
    ListGeoTargetsResponse,
)
from google.ads.admanager_v1.types.goal import Goal
from google.ads.admanager_v1.types.goal_enums import GoalTypeEnum, UnitTypeEnum
from google.ads.admanager_v1.types.label_messages import Label
from google.ads.admanager_v1.types.line_item_enums import LineItemTypeEnum
from google.ads.admanager_v1.types.line_item_messages import LineItem
from google.ads.admanager_v1.types.line_item_service import (
    GetLineItemRequest,
    ListLineItemsRequest,
    ListLineItemsResponse,
)
from google.ads.admanager_v1.types.live_stream_event_messages import LiveStreamEvent
from google.ads.admanager_v1.types.mobile_carrier_messages import MobileCarrier
from google.ads.admanager_v1.types.mobile_carrier_service import (
    GetMobileCarrierRequest,
    ListMobileCarriersRequest,
    ListMobileCarriersResponse,
)
from google.ads.admanager_v1.types.mobile_device_messages import MobileDevice
from google.ads.admanager_v1.types.mobile_device_service import (
    GetMobileDeviceRequest,
    ListMobileDevicesRequest,
    ListMobileDevicesResponse,
)
from google.ads.admanager_v1.types.mobile_device_submodel_messages import (
    MobileDeviceSubmodel,
)
from google.ads.admanager_v1.types.mobile_device_submodel_service import (
    GetMobileDeviceSubmodelRequest,
    ListMobileDeviceSubmodelsRequest,
    ListMobileDeviceSubmodelsResponse,
)
from google.ads.admanager_v1.types.network_messages import Network
from google.ads.admanager_v1.types.network_service import (
    GetNetworkRequest,
    ListNetworksRequest,
    ListNetworksResponse,
)
from google.ads.admanager_v1.types.operating_system_messages import OperatingSystem
from google.ads.admanager_v1.types.operating_system_service import (
    GetOperatingSystemRequest,
    ListOperatingSystemsRequest,
    ListOperatingSystemsResponse,
)
from google.ads.admanager_v1.types.operating_system_version_messages import (
    OperatingSystemVersion,
)
from google.ads.admanager_v1.types.operating_system_version_service import (
    GetOperatingSystemVersionRequest,
    ListOperatingSystemVersionsRequest,
    ListOperatingSystemVersionsResponse,
)
from google.ads.admanager_v1.types.order_enums import OrderStatusEnum
from google.ads.admanager_v1.types.order_messages import Order
from google.ads.admanager_v1.types.order_service import (
    GetOrderRequest,
    ListOrdersRequest,
    ListOrdersResponse,
)
from google.ads.admanager_v1.types.placement_enums import PlacementStatusEnum
from google.ads.admanager_v1.types.placement_messages import Placement
from google.ads.admanager_v1.types.placement_service import (
    BatchActivatePlacementsRequest,
    BatchActivatePlacementsResponse,
    BatchArchivePlacementsRequest,
    BatchArchivePlacementsResponse,
    BatchCreatePlacementsRequest,
    BatchCreatePlacementsResponse,
    BatchDeactivatePlacementsRequest,
    BatchDeactivatePlacementsResponse,
    BatchUpdatePlacementsRequest,
    BatchUpdatePlacementsResponse,
    CreatePlacementRequest,
    GetPlacementRequest,
    ListPlacementsRequest,
    ListPlacementsResponse,
    UpdatePlacementRequest,
)
from google.ads.admanager_v1.types.private_auction_deal_messages import (
    PrivateAuctionDeal,
)
from google.ads.admanager_v1.types.private_auction_deal_service import (
    CreatePrivateAuctionDealRequest,
    GetPrivateAuctionDealRequest,
    ListPrivateAuctionDealsRequest,
    ListPrivateAuctionDealsResponse,
    UpdatePrivateAuctionDealRequest,
)
from google.ads.admanager_v1.types.private_auction_messages import PrivateAuction
from google.ads.admanager_v1.types.private_auction_service import (
    CreatePrivateAuctionRequest,
    GetPrivateAuctionRequest,
    ListPrivateAuctionsRequest,
    ListPrivateAuctionsResponse,
    UpdatePrivateAuctionRequest,
)
from google.ads.admanager_v1.types.private_marketplace_enums import (
    PrivateMarketplaceDealStatusEnum,
)
from google.ads.admanager_v1.types.programmatic_buyer_messages import ProgrammaticBuyer
from google.ads.admanager_v1.types.programmatic_buyer_service import (
    GetProgrammaticBuyerRequest,
    ListProgrammaticBuyersRequest,
    ListProgrammaticBuyersResponse,
)
from google.ads.admanager_v1.types.report_definition import ReportDefinition
from google.ads.admanager_v1.types.report_messages import (
    Report,
    ReportDataTable,
    ScheduleOptions,
)
from google.ads.admanager_v1.types.report_service import (
    CreateReportRequest,
    FetchReportResultRowsRequest,
    FetchReportResultRowsResponse,
    GetReportRequest,
    ListReportsRequest,
    ListReportsResponse,
    RunReportMetadata,
    RunReportRequest,
    RunReportResponse,
    UpdateReportRequest,
)
from google.ads.admanager_v1.types.report_value import ReportValue
from google.ads.admanager_v1.types.request_platform_enum import RequestPlatformEnum
from google.ads.admanager_v1.types.role_enums import RoleStatusEnum
from google.ads.admanager_v1.types.role_messages import Role
from google.ads.admanager_v1.types.role_service import (
    GetRoleRequest,
    ListRolesRequest,
    ListRolesResponse,
)
from google.ads.admanager_v1.types.site_enums import (
    SiteApprovalStatusEnum,
    SiteDisapprovalReasonEnum,
)
from google.ads.admanager_v1.types.site_messages import DisapprovalReason, Site
from google.ads.admanager_v1.types.site_service import (
    BatchCreateSitesRequest,
    BatchCreateSitesResponse,
    BatchDeactivateSitesRequest,
    BatchDeactivateSitesResponse,
    BatchSubmitSitesForApprovalRequest,
    BatchSubmitSitesForApprovalResponse,
    BatchUpdateSitesRequest,
    BatchUpdateSitesResponse,
    CreateSiteRequest,
    GetSiteRequest,
    ListSitesRequest,
    ListSitesResponse,
    UpdateSiteRequest,
)
from google.ads.admanager_v1.types.size import Size
from google.ads.admanager_v1.types.size_type_enum import SizeTypeEnum
from google.ads.admanager_v1.types.targeted_video_bumper_type_enum import (
    TargetedVideoBumperTypeEnum,
)
from google.ads.admanager_v1.types.targeting import (
    AdUnitTargeting,
    AudienceSegmentTargeting,
    BandwidthTargeting,
    BrowserLanguageTargeting,
    BrowserTargeting,
    CmsMetadataTargeting,
    ContentTargeting,
    CustomTargeting,
    CustomTargetingClause,
    CustomTargetingLiteral,
    DataSegmentTargeting,
    DeviceCapabilityTargeting,
    DeviceCategoryTargeting,
    DeviceManufacturerTargeting,
    FirstPartyMobileApplicationTargeting,
    GeoTargeting,
    InventoryTargeting,
    MobileApplicationTargeting,
    MobileCarrierTargeting,
    OperatingSystemTargeting,
    RequestPlatformTargeting,
    Targeting,
    TechnologyTargeting,
    UserDomainTargeting,
    VideoPosition,
    VideoPositionTargeting,
)
from google.ads.admanager_v1.types.taxonomy_category_messages import TaxonomyCategory
from google.ads.admanager_v1.types.taxonomy_category_service import (
    GetTaxonomyCategoryRequest,
    ListTaxonomyCategoriesRequest,
    ListTaxonomyCategoriesResponse,
)
from google.ads.admanager_v1.types.taxonomy_type_enum import TaxonomyTypeEnum
from google.ads.admanager_v1.types.team_enums import TeamAccessTypeEnum, TeamStatusEnum
from google.ads.admanager_v1.types.team_messages import Team
from google.ads.admanager_v1.types.team_service import (
    BatchActivateTeamsRequest,
    BatchActivateTeamsResponse,
    BatchCreateTeamsRequest,
    BatchCreateTeamsResponse,
    BatchDeactivateTeamsRequest,
    BatchDeactivateTeamsResponse,
    BatchUpdateTeamsRequest,
    BatchUpdateTeamsResponse,
    CreateTeamRequest,
    GetTeamRequest,
    ListTeamsRequest,
    ListTeamsResponse,
    UpdateTeamRequest,
)
from google.ads.admanager_v1.types.time_unit_enum import TimeUnitEnum
from google.ads.admanager_v1.types.user_messages import User
from google.ads.admanager_v1.types.user_service import GetUserRequest
from google.ads.admanager_v1.types.video_position_enum import VideoPositionEnum
from google.ads.admanager_v1.types.web_property import WebProperty

__all__ = (
    "AdBreakServiceClient",
    "AdReviewCenterAdServiceClient",
    "AdUnitServiceClient",
    "ApplicationServiceClient",
    "AudienceSegmentServiceClient",
    "BandwidthGroupServiceClient",
    "BrowserLanguageServiceClient",
    "BrowserServiceClient",
    "CmsMetadataKeyServiceClient",
    "CmsMetadataValueServiceClient",
    "CompanyServiceClient",
    "ContactServiceClient",
    "ContentBundleServiceClient",
    "ContentLabelServiceClient",
    "ContentServiceClient",
    "CreativeTemplateServiceClient",
    "CustomFieldServiceClient",
    "CustomTargetingKeyServiceClient",
    "CustomTargetingValueServiceClient",
    "DeviceCapabilityServiceClient",
    "DeviceCategoryServiceClient",
    "DeviceManufacturerServiceClient",
    "EntitySignalsMappingServiceClient",
    "GeoTargetServiceClient",
    "LineItemServiceClient",
    "MobileCarrierServiceClient",
    "MobileDeviceServiceClient",
    "MobileDeviceSubmodelServiceClient",
    "NetworkServiceClient",
    "OperatingSystemServiceClient",
    "OperatingSystemVersionServiceClient",
    "OrderServiceClient",
    "PlacementServiceClient",
    "PrivateAuctionDealServiceClient",
    "PrivateAuctionServiceClient",
    "ProgrammaticBuyerServiceClient",
    "ReportServiceClient",
    "RoleServiceClient",
    "SiteServiceClient",
    "TaxonomyCategoryServiceClient",
    "TeamServiceClient",
    "UserServiceClient",
    "AdBreak",
    "CreateAdBreakRequest",
    "DeleteAdBreakRequest",
    "GetAdBreakRequest",
    "ListAdBreaksRequest",
    "ListAdBreaksResponse",
    "UpdateAdBreakRequest",
    "AdReviewCenterAdStatusEnum",
    "AdReviewCenterAd",
    "BatchAdReviewCenterAdsOperationMetadata",
    "BatchAllowAdReviewCenterAdsRequest",
    "BatchAllowAdReviewCenterAdsResponse",
    "BatchBlockAdReviewCenterAdsRequest",
    "BatchBlockAdReviewCenterAdsResponse",
    "SearchAdReviewCenterAdsRequest",
    "SearchAdReviewCenterAdsResponse",
    "AdUnitStatusEnum",
    "SmartSizeModeEnum",
    "TargetWindowEnum",
    "AdUnit",
    "AdUnitParent",
    "AdUnitSize",
    "LabelFrequencyCap",
    "BatchActivateAdUnitsRequest",
    "BatchActivateAdUnitsResponse",
    "BatchArchiveAdUnitsRequest",
    "BatchArchiveAdUnitsResponse",
    "BatchCreateAdUnitsRequest",
    "BatchCreateAdUnitsResponse",
    "BatchDeactivateAdUnitsRequest",
    "BatchDeactivateAdUnitsResponse",
    "BatchUpdateAdUnitsRequest",
    "BatchUpdateAdUnitsResponse",
    "CreateAdUnitRequest",
    "GetAdUnitRequest",
    "ListAdUnitSizesRequest",
    "ListAdUnitSizesResponse",
    "ListAdUnitsRequest",
    "ListAdUnitsResponse",
    "UpdateAdUnitRequest",
    "AdManagerError",
    "Application",
    "GetApplicationRequest",
    "ListApplicationsRequest",
    "ListApplicationsResponse",
    "AppliedLabel",
    "AudienceSegment",
    "GetAudienceSegmentRequest",
    "ListAudienceSegmentsRequest",
    "ListAudienceSegmentsResponse",
    "BandwidthGroup",
    "GetBandwidthGroupRequest",
    "ListBandwidthGroupsRequest",
    "ListBandwidthGroupsResponse",
    "BrowserLanguage",
    "GetBrowserLanguageRequest",
    "ListBrowserLanguagesRequest",
    "ListBrowserLanguagesResponse",
    "Browser",
    "GetBrowserRequest",
    "ListBrowsersRequest",
    "ListBrowsersResponse",
    "CmsMetadataKeyStatusEnum",
    "CmsMetadataKey",
    "GetCmsMetadataKeyRequest",
    "ListCmsMetadataKeysRequest",
    "ListCmsMetadataKeysResponse",
    "CmsMetadataValueStatusEnum",
    "CmsMetadataValue",
    "GetCmsMetadataValueRequest",
    "ListCmsMetadataValuesRequest",
    "ListCmsMetadataValuesResponse",
    "CompanyCreditStatusEnum",
    "CompanyTypeEnum",
    "Company",
    "GetCompanyRequest",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "ContactStatusEnum",
    "Contact",
    "BatchCreateContactsRequest",
    "BatchCreateContactsResponse",
    "BatchUpdateContactsRequest",
    "BatchUpdateContactsResponse",
    "CreateContactRequest",
    "GetContactRequest",
    "ListContactsRequest",
    "ListContactsResponse",
    "UpdateContactRequest",
    "ContentBundle",
    "GetContentBundleRequest",
    "ListContentBundlesRequest",
    "ListContentBundlesResponse",
    "ContentLabel",
    "GetContentLabelRequest",
    "ListContentLabelsRequest",
    "ListContentLabelsResponse",
    "Content",
    "GetContentRequest",
    "ListContentRequest",
    "ListContentResponse",
    "CreativeTemplateStatusEnum",
    "CreativeTemplateTypeEnum",
    "CreativeTemplate",
    "CreativeTemplateVariable",
    "GetCreativeTemplateRequest",
    "ListCreativeTemplatesRequest",
    "ListCreativeTemplatesResponse",
    "CreativeTemplateVariableUrlTypeEnum",
    "CustomFieldDataTypeEnum",
    "CustomFieldEntityTypeEnum",
    "CustomFieldStatusEnum",
    "CustomFieldVisibilityEnum",
    "CustomField",
    "CustomFieldOption",
    "BatchActivateCustomFieldsRequest",
    "BatchActivateCustomFieldsResponse",
    "BatchCreateCustomFieldsRequest",
    "BatchCreateCustomFieldsResponse",
    "BatchDeactivateCustomFieldsRequest",
    "BatchDeactivateCustomFieldsResponse",
    "BatchUpdateCustomFieldsRequest",
    "BatchUpdateCustomFieldsResponse",
    "CreateCustomFieldRequest",
    "GetCustomFieldRequest",
    "ListCustomFieldsRequest",
    "ListCustomFieldsResponse",
    "UpdateCustomFieldRequest",
    "CustomFieldValue",
    "CustomTargetingKeyReportableTypeEnum",
    "CustomTargetingKeyStatusEnum",
    "CustomTargetingKeyTypeEnum",
    "CustomTargetingKey",
    "BatchActivateCustomTargetingKeysRequest",
    "BatchActivateCustomTargetingKeysResponse",
    "BatchCreateCustomTargetingKeysRequest",
    "BatchCreateCustomTargetingKeysResponse",
    "BatchDeactivateCustomTargetingKeysRequest",
    "BatchDeactivateCustomTargetingKeysResponse",
    "BatchUpdateCustomTargetingKeysRequest",
    "BatchUpdateCustomTargetingKeysResponse",
    "CreateCustomTargetingKeyRequest",
    "GetCustomTargetingKeyRequest",
    "ListCustomTargetingKeysRequest",
    "ListCustomTargetingKeysResponse",
    "UpdateCustomTargetingKeyRequest",
    "CustomTargetingValueMatchTypeEnum",
    "CustomTargetingValueStatusEnum",
    "CustomTargetingValue",
    "GetCustomTargetingValueRequest",
    "ListCustomTargetingValuesRequest",
    "ListCustomTargetingValuesResponse",
    "DealBuyerPermissionTypeEnum",
    "DeviceCapability",
    "GetDeviceCapabilityRequest",
    "ListDeviceCapabilitiesRequest",
    "ListDeviceCapabilitiesResponse",
    "DeviceCategory",
    "GetDeviceCategoryRequest",
    "ListDeviceCategoriesRequest",
    "ListDeviceCategoriesResponse",
    "DeviceManufacturer",
    "GetDeviceManufacturerRequest",
    "ListDeviceManufacturersRequest",
    "ListDeviceManufacturersResponse",
    "AdBreakStateEnum",
    "EntitySignalsMapping",
    "BatchCreateEntitySignalsMappingsRequest",
    "BatchCreateEntitySignalsMappingsResponse",
    "BatchUpdateEntitySignalsMappingsRequest",
    "BatchUpdateEntitySignalsMappingsResponse",
    "CreateEntitySignalsMappingRequest",
    "GetEntitySignalsMappingRequest",
    "ListEntitySignalsMappingsRequest",
    "ListEntitySignalsMappingsResponse",
    "UpdateEntitySignalsMappingRequest",
    "EnvironmentTypeEnum",
    "ExchangeSyndicationProductEnum",
    "FrequencyCap",
    "GeoTarget",
    "GetGeoTargetRequest",
    "ListGeoTargetsRequest",
    "ListGeoTargetsResponse",
    "Goal",
    "GoalTypeEnum",
    "UnitTypeEnum",
    "Label",
    "LineItemTypeEnum",
    "LineItem",
    "GetLineItemRequest",
    "ListLineItemsRequest",
    "ListLineItemsResponse",
    "LiveStreamEvent",
    "MobileCarrier",
    "GetMobileCarrierRequest",
    "ListMobileCarriersRequest",
    "ListMobileCarriersResponse",
    "MobileDevice",
    "GetMobileDeviceRequest",
    "ListMobileDevicesRequest",
    "ListMobileDevicesResponse",
    "MobileDeviceSubmodel",
    "GetMobileDeviceSubmodelRequest",
    "ListMobileDeviceSubmodelsRequest",
    "ListMobileDeviceSubmodelsResponse",
    "Network",
    "GetNetworkRequest",
    "ListNetworksRequest",
    "ListNetworksResponse",
    "OperatingSystem",
    "GetOperatingSystemRequest",
    "ListOperatingSystemsRequest",
    "ListOperatingSystemsResponse",
    "OperatingSystemVersion",
    "GetOperatingSystemVersionRequest",
    "ListOperatingSystemVersionsRequest",
    "ListOperatingSystemVersionsResponse",
    "OrderStatusEnum",
    "Order",
    "GetOrderRequest",
    "ListOrdersRequest",
    "ListOrdersResponse",
    "PlacementStatusEnum",
    "Placement",
    "BatchActivatePlacementsRequest",
    "BatchActivatePlacementsResponse",
    "BatchArchivePlacementsRequest",
    "BatchArchivePlacementsResponse",
    "BatchCreatePlacementsRequest",
    "BatchCreatePlacementsResponse",
    "BatchDeactivatePlacementsRequest",
    "BatchDeactivatePlacementsResponse",
    "BatchUpdatePlacementsRequest",
    "BatchUpdatePlacementsResponse",
    "CreatePlacementRequest",
    "GetPlacementRequest",
    "ListPlacementsRequest",
    "ListPlacementsResponse",
    "UpdatePlacementRequest",
    "PrivateAuctionDeal",
    "CreatePrivateAuctionDealRequest",
    "GetPrivateAuctionDealRequest",
    "ListPrivateAuctionDealsRequest",
    "ListPrivateAuctionDealsResponse",
    "UpdatePrivateAuctionDealRequest",
    "PrivateAuction",
    "CreatePrivateAuctionRequest",
    "GetPrivateAuctionRequest",
    "ListPrivateAuctionsRequest",
    "ListPrivateAuctionsResponse",
    "UpdatePrivateAuctionRequest",
    "PrivateMarketplaceDealStatusEnum",
    "ProgrammaticBuyer",
    "GetProgrammaticBuyerRequest",
    "ListProgrammaticBuyersRequest",
    "ListProgrammaticBuyersResponse",
    "ReportDefinition",
    "Report",
    "ReportDataTable",
    "ScheduleOptions",
    "CreateReportRequest",
    "FetchReportResultRowsRequest",
    "FetchReportResultRowsResponse",
    "GetReportRequest",
    "ListReportsRequest",
    "ListReportsResponse",
    "RunReportMetadata",
    "RunReportRequest",
    "RunReportResponse",
    "UpdateReportRequest",
    "ReportValue",
    "RequestPlatformEnum",
    "RoleStatusEnum",
    "Role",
    "GetRoleRequest",
    "ListRolesRequest",
    "ListRolesResponse",
    "SiteApprovalStatusEnum",
    "SiteDisapprovalReasonEnum",
    "DisapprovalReason",
    "Site",
    "BatchCreateSitesRequest",
    "BatchCreateSitesResponse",
    "BatchDeactivateSitesRequest",
    "BatchDeactivateSitesResponse",
    "BatchSubmitSitesForApprovalRequest",
    "BatchSubmitSitesForApprovalResponse",
    "BatchUpdateSitesRequest",
    "BatchUpdateSitesResponse",
    "CreateSiteRequest",
    "GetSiteRequest",
    "ListSitesRequest",
    "ListSitesResponse",
    "UpdateSiteRequest",
    "Size",
    "SizeTypeEnum",
    "TargetedVideoBumperTypeEnum",
    "AdUnitTargeting",
    "AudienceSegmentTargeting",
    "BandwidthTargeting",
    "BrowserLanguageTargeting",
    "BrowserTargeting",
    "CmsMetadataTargeting",
    "ContentTargeting",
    "CustomTargeting",
    "CustomTargetingClause",
    "CustomTargetingLiteral",
    "DataSegmentTargeting",
    "DeviceCapabilityTargeting",
    "DeviceCategoryTargeting",
    "DeviceManufacturerTargeting",
    "FirstPartyMobileApplicationTargeting",
    "GeoTargeting",
    "InventoryTargeting",
    "MobileApplicationTargeting",
    "MobileCarrierTargeting",
    "OperatingSystemTargeting",
    "RequestPlatformTargeting",
    "Targeting",
    "TechnologyTargeting",
    "UserDomainTargeting",
    "VideoPosition",
    "VideoPositionTargeting",
    "TaxonomyCategory",
    "GetTaxonomyCategoryRequest",
    "ListTaxonomyCategoriesRequest",
    "ListTaxonomyCategoriesResponse",
    "TaxonomyTypeEnum",
    "TeamAccessTypeEnum",
    "TeamStatusEnum",
    "Team",
    "BatchActivateTeamsRequest",
    "BatchActivateTeamsResponse",
    "BatchCreateTeamsRequest",
    "BatchCreateTeamsResponse",
    "BatchDeactivateTeamsRequest",
    "BatchDeactivateTeamsResponse",
    "BatchUpdateTeamsRequest",
    "BatchUpdateTeamsResponse",
    "CreateTeamRequest",
    "GetTeamRequest",
    "ListTeamsRequest",
    "ListTeamsResponse",
    "UpdateTeamRequest",
    "TimeUnitEnum",
    "User",
    "GetUserRequest",
    "VideoPositionEnum",
    "WebProperty",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import report_definition, report_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "RunReportRequest",
        "RunReportMetadata",
        "RunReportResponse",
        "GetReportRequest",
        "ListReportsRequest",
        "ListReportsResponse",
        "CreateReportRequest",
        "UpdateReportRequest",
        "FetchReportResultRowsRequest",
        "FetchReportResultRowsResponse",
    },
)


class RunReportRequest(proto.Message):
    r"""Request message for a running a report.

    Attributes:
        name (str):
            Required. The report to run. Format:
            ``networks/{network_code}/reports/{report_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class RunReportMetadata(proto.Message):
    r"""``RunReport`` operation metadata.

    Attributes:
        percent_complete (int):
            An estimate of how close this report is to
            being completed. Will always be 100 for failed
            and completed reports.
        report (str):
            The result's parent report.
    """

    percent_complete: int = proto.Field(
        proto.INT32,
        number=2,
    )
    report: str = proto.Field(
        proto.STRING,
        number=4,
    )


class RunReportResponse(proto.Message):
    r"""Response message for a completed ``RunReport`` operation.

    Attributes:
        report_result (str):
            The unique name of the generated result. Use with
            ``FetchReportResultRows`` to retrieve data.
    """

    report_result: str = proto.Field(
        proto.STRING,
        number=1,
    )


class GetReportRequest(proto.Message):
    r"""Request object for ``GetReport`` method.

    Attributes:
        name (str):
            Required. The resource name of the report. Format:
            ``networks/{network_code}/reports/{report_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListReportsRequest(proto.Message):
    r"""Request object for ``ListReports`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of reports.
            Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of ``Reports`` to return. The
            service may return fewer than this value. If unspecified, at
            most 50 ``Reports`` will be returned. The maximum value is
            1000; values greater than 1000 will be coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListReports`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListReports`` must match the call that provided the page
            token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListReportsResponse(proto.Message):
    r"""Response object for ``ListReportsResponse`` containing matching
    ``Report`` objects.

    Attributes:
        reports (MutableSequence[google.ads.admanager_v1.types.Report]):
            The ``Report`` objects from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of ``Report`` objects. If a filter was included
            in the request, this reflects the total number after the
            filtering is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    reports: MutableSequence[report_messages.Report] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=report_messages.Report,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class CreateReportRequest(proto.Message):
    r"""Request object for ``CreateReport`` method.

    Attributes:
        parent (str):
            Required. The parent resource where this ``Report`` will be
            created. Format: ``networks/{network_code}``
        report (google.ads.admanager_v1.types.Report):
            Required. The ``Report`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    report: report_messages.Report = proto.Field(
        proto.MESSAGE,
        number=2,
        message=report_messages.Report,
    )


class UpdateReportRequest(proto.Message):
    r"""Request object for ``UpdateReport`` method.

    Attributes:
        report (google.ads.admanager_v1.types.Report):
            Required. The ``Report`` to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update.
    """

    report: report_messages.Report = proto.Field(
        proto.MESSAGE,
        number=1,
        message=report_messages.Report,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class FetchReportResultRowsRequest(proto.Message):
    r"""The request message for the fetch report result rows
    endpoint.

    Attributes:
        name (str):
            The report result being fetched. Format:
            ``networks/{network_code}/reports/{report_id}/results/{report_result_id}``
        page_size (int):
            Optional. The maximum number of rows to
            return. The service may return fewer than this
            value. If unspecified, at most 1,000 rows will
            be returned. The maximum value is 10,000; values
            greater than 10,000 will be reduced to 10,000.
        page_token (str):
            Optional. A page token, received from a previous
            ``FetchReportResultRows`` call. Provide this to retrieve the
            second and subsequent batches of rows.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class FetchReportResultRowsResponse(proto.Message):
    r"""The response message for the fetch report result rows
    endpoint.

    Attributes:
        rows (MutableSequence[google.ads.admanager_v1.types.ReportDataTable.Row]):
            Up to ``page_size`` rows of report data.
        run_time (google.protobuf.timestamp_pb2.Timestamp):
            The time at which the report was scheduled to
            run. For non-scheduled reports, this is the time
            at which the report was requested to be run.
        date_ranges (MutableSequence[google.ads.admanager_v1.types.ReportDefinition.DateRange.FixedDateRange]):
            The computed fixed date ranges this report includes. Only
            returned with the first page of results (when page_token is
            not included in the request).
        comparison_date_ranges (MutableSequence[google.ads.admanager_v1.types.ReportDefinition.DateRange.FixedDateRange]):
            The computed comparison fixed date ranges this report
            includes. Only returned with the first page of results (when
            page_token is not included in the request).
        total_row_count (int):
            The total number of rows available from this report. Useful
            for pagination. Only returned with the first page of results
            (when page_token is not included in the request).
        next_page_token (str):
            A token that can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    rows: MutableSequence[report_messages.ReportDataTable.Row] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=report_messages.ReportDataTable.Row,
    )
    run_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    date_ranges: MutableSequence[
        report_definition.ReportDefinition.DateRange.FixedDateRange
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=report_definition.ReportDefinition.DateRange.FixedDateRange,
    )
    comparison_date_ranges: MutableSequence[
        report_definition.ReportDefinition.DateRange.FixedDateRange
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=report_definition.ReportDefinition.DateRange.FixedDateRange,
    )
    total_row_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=6,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomTargetingValueStatusEnum",
        "CustomTargetingValueMatchTypeEnum",
    },
)


class CustomTargetingValueStatusEnum(proto.Message):
    r"""Wrapper message for
    [CustomTargetingValueStatus][google.ads.admanager.v1.CustomTargetingValueStatusEnum.CustomTargetingValueStatus]

    """

    class CustomTargetingValueStatus(proto.Enum):
        r"""Status of the custom targeting value.

        Values:
            CUSTOM_TARGETING_VALUE_STATUS_UNSPECIFIED (0):
                Not specified value.
            ACTIVE (1):
                Custom targeting value is active.
            INACTIVE (2):
                Custom targeting value is inactive.
        """
        CUSTOM_TARGETING_VALUE_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


class CustomTargetingValueMatchTypeEnum(proto.Message):
    r"""Wrapper message for
    [CustomTargetingValueMatchType][google.ads.admanager.v1.CustomTargetingValueMatchTypeEnum.CustomTargetingValueMatchType]

    """

    class CustomTargetingValueMatchType(proto.Enum):
        r"""Match type of the custom targeting value.

        Values:
            CUSTOM_TARGETING_VALUE_MATCH_TYPE_UNSPECIFIED (0):
                Not specified value.
            EXACT (1):
                Used for exact matching. For example, the
                targeting value car=honda will only match to the
                ad request car=honda.
            BROAD (2):
                Used for lenient matching when at least one
                of the words in the ad request matches the
                targeted value. The targeting value car=honda
                will match to ad requests containing the word
                honda. So ad requests car=honda or car=honda
                civic or car=buy honda or car=how much does a
                honda cost will all have the line item
                delivered.
                This match type can not be used within an
                audience segment rule.
            PREFIX (3):
                Used for 'starts with' matching when the
                first few characters in the ad request match all
                of the characters in the targeted value. The
                targeting value car=honda will match to ad
                requests car=honda or car=hondas for sale but
                not to car=I want a honda.
            BROAD_PREFIX (4):
                This is a combination of MatchType#BROAD and
                MatchType#PREFIX matching. The targeting value
                car=honda will match to ad requests that contain
                words that start with the characters in the
                targeted value, for example with car=civic
                hondas.
                This match type can not be used within an
                audience segment rule.
            SUFFIX (5):
                Used for 'ends with' matching when the last
                characters in the ad request match all of the
                characters in the targeted value. The targeting
                value car=honda will match with ad requests
                car=honda or car=I want a honda but not to
                car=hondas for sale.
                This match type can not be used within line item
                targeting.
            CONTAINS (6):
                Used for 'within' matching when the string in
                the ad request contains the string in the
                targeted value. The targeting value car=honda
                will match with ad requests car=honda, car=I
                want a honda, and also with car=hondas for sale,
                but not with car=misspelled hond a. This match
                type can not be used within line item targeting.
        """
        CUSTOM_TARGETING_VALUE_MATCH_TYPE_UNSPECIFIED = 0
        EXACT = 1
        BROAD = 2
        PREFIX = 3
        BROAD_PREFIX = 4
        SUFFIX = 5
        CONTAINS = 6


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "PrivateAuction",
    },
)


class PrivateAuction(proto.Message):
    r"""The ``PrivateAuction`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``PrivateAuction``.
            Format:
            ``networks/{network_code}/privateAuctions/{private_auction_id}``
        private_auction_id (int):
            Output only. ``PrivateAuction`` ID.

            This field is a member of `oneof`_ ``_private_auction_id``.
        display_name (str):
            Required. Display name of the ``PrivateAuction``. This
            attribute has a maximum length of 255 bytes.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. Description of the ``PrivateAuction``. This
            attribute has a maximum length of 4096 bytes.

            This field is a member of `oneof`_ ``_description``.
        seller_contact_users (MutableSequence[str]):
            Optional. The resource names of the seller contact users
            associated with this ``PrivateAuction``. Format:
            ``networks/{network_code}/users/{user_id}``
        archived (bool):
            Output only. Whether the ``PrivateAuction`` is archived.

            This field is a member of `oneof`_ ``_archived``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the
            PrivateAuction was created.

            This field is a member of `oneof`_ ``_create_time``.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the
            PrivateAuction was last updated.

            This field is a member of `oneof`_ ``_update_time``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    private_auction_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    seller_contact_users: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=9,
    )
    archived: bool = proto.Field(
        proto.BOOL,
        number=6,
        optional=True,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "ReportValue",
    },
)


class ReportValue(proto.Message):
    r"""Represents a single value in a report.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        int_value (int):
            For integer values.

            This field is a member of `oneof`_ ``value``.
        double_value (float):
            For double values.

            This field is a member of `oneof`_ ``value``.
        string_value (str):
            For string values.

            This field is a member of `oneof`_ ``value``.
        bool_value (bool):
            For boolean values.

            This field is a member of `oneof`_ ``value``.
        int_list_value (google.ads.admanager_v1.types.ReportValue.IntList):
            For lists of integer values.

            This field is a member of `oneof`_ ``value``.
        string_list_value (google.ads.admanager_v1.types.ReportValue.StringList):
            For lists of string values.

            This field is a member of `oneof`_ ``value``.
        double_list_value (google.ads.admanager_v1.types.ReportValue.DoubleList):
            For lists of double values.

            This field is a member of `oneof`_ ``value``.
        bytes_value (bytes):
            For bytes values.

            This field is a member of `oneof`_ ``value``.
    """

    class IntList(proto.Message):
        r"""A list of integer values.

        Attributes:
            values (MutableSequence[int]):
                The values
        """

        values: MutableSequence[int] = proto.RepeatedField(
            proto.INT64,
            number=1,
        )

    class StringList(proto.Message):
        r"""A list of string values.

        Attributes:
            values (MutableSequence[str]):
                The values
        """

        values: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )

    class DoubleList(proto.Message):
        r"""A list of double values.

        Attributes:
            values (MutableSequence[float]):
                The values
        """

        values: MutableSequence[float] = proto.RepeatedField(
            proto.DOUBLE,
            number=1,
        )

    int_value: int = proto.Field(
        proto.INT64,
        number=1,
        oneof="value",
    )
    double_value: float = proto.Field(
        proto.DOUBLE,
        number=2,
        oneof="value",
    )
    string_value: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="value",
    )
    bool_value: bool = proto.Field(
        proto.BOOL,
        number=4,
        oneof="value",
    )
    int_list_value: IntList = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="value",
        message=IntList,
    )
    string_list_value: StringList = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="value",
        message=StringList,
    )
    double_list_value: DoubleList = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="value",
        message=DoubleList,
    )
    bytes_value: bytes = proto.Field(
        proto.BYTES,
        number=8,
        oneof="value",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import placement_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Placement",
    },
)


class Placement(proto.Message):
    r"""The ``Placement`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Placement``. Format:
            ``networks/{network_code}/placements/{placement_id}``
        placement_id (int):
            Output only. ``Placement`` ID.
        display_name (str):
            Required. The display name of the placement.
            This attribute has a maximum length of 255
            characters.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. A description of the Placement.
            This attribute has a maximum length of 65,535
            characters.

            This field is a member of `oneof`_ ``_description``.
        placement_code (str):
            Output only. A string used to uniquely
            identify the Placement for purposes of serving
            the ad. This attribute is assigned by Google.

            This field is a member of `oneof`_ ``_placement_code``.
        status (google.ads.admanager_v1.types.PlacementStatusEnum.PlacementStatus):
            Output only. The status of the Placement.

            This field is a member of `oneof`_ ``_status``.
        targeted_ad_units (MutableSequence[str]):
            Optional. The resource names of AdUnits that constitute the
            Placement. Format:
            "networks/{network_code}/adUnits/{ad_unit}".
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant this Placement was
            last modified.

            This field is a member of `oneof`_ ``_update_time``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    placement_id: int = proto.Field(
        proto.INT64,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    placement_code: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    status: placement_enums.PlacementStatusEnum.PlacementStatus = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=placement_enums.PlacementStatusEnum.PlacementStatus,
    )
    targeted_ad_units: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=9,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import custom_targeting_value_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomTargetingValue",
    },
)


class CustomTargetingValue(proto.Message):
    r"""The ``CustomTargetingValue`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the
            ``CustomTargetingValue``. Format:
            ``networks/{network_code}/customTargetingValues/{custom_targeting_value_id}``
        custom_targeting_key (str):
            Required. Immutable. The resource name of the
            ``CustomTargetingKey``. Format:
            ``networks/{network_code}/customTargetingKeys/{custom_targeting_key_id}``

            This field is a member of `oneof`_ ``_custom_targeting_key``.
        ad_tag_name (str):
            Immutable. Name of the ``CustomTargetingValue``. Values can
            contain up to 40 characters each. You can use alphanumeric
            characters and symbols other than the following: ", ', =, !,
            +, #, \*, ~, ;, ^, (, ), <, >, [, ]. Values are not
            data-specific; all values are treated as strings. For
            example, instead of using "age>=18 AND <=34", try "18-34".

            This field is a member of `oneof`_ ``_ad_tag_name``.
        display_name (str):
            Optional. Descriptive name for the ``CustomTargetingValue``.

            This field is a member of `oneof`_ ``_display_name``.
        match_type (google.ads.admanager_v1.types.CustomTargetingValueMatchTypeEnum.CustomTargetingValueMatchType):
            Required. Immutable. The way in which the
            CustomTargetingValue.name strings will be
            matched.

            This field is a member of `oneof`_ ``_match_type``.
        status (google.ads.admanager_v1.types.CustomTargetingValueStatusEnum.CustomTargetingValueStatus):
            Output only. Status of the ``CustomTargetingValue``.

            This field is a member of `oneof`_ ``_status``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    custom_targeting_key: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    ad_tag_name: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    match_type: custom_targeting_value_enums.CustomTargetingValueMatchTypeEnum.CustomTargetingValueMatchType = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=custom_targeting_value_enums.CustomTargetingValueMatchTypeEnum.CustomTargetingValueMatchType,
    )
    status: custom_targeting_value_enums.CustomTargetingValueStatusEnum.CustomTargetingValueStatus = proto.Field(
        proto.ENUM,
        number=7,
        optional=True,
        enum=custom_targeting_value_enums.CustomTargetingValueStatusEnum.CustomTargetingValueStatus,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "OrderStatusEnum",
    },
)


class OrderStatusEnum(proto.Message):
    r"""Wrapper message for
    [OrderStatus][google.ads.admanager.v1.OrderStatusEnum.OrderStatus].

    """

    class OrderStatus(proto.Enum):
        r"""The status of an Order.

        Values:
            ORDER_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            DRAFT (2):
                Indicates that the Order has just been
                created but no approval has been requested yet.
            PENDING_APPROVAL (3):
                Indicates that a request for approval for the
                Order has been made.
            APPROVED (4):
                Indicates that the Order has been approved
                and is ready to serve.
            DISAPPROVED (5):
                Indicates that the Order has been disapproved
                and is not eligible to serve.
            PAUSED (6):
                This is a legacy state. Paused status should
                be checked on LineItems within the order.
            CANCELED (7):
                Indicates that the Order has been canceled
                and cannot serve.
            DELETED (8):
                Indicates that the Order has been deleted.
        """
        ORDER_STATUS_UNSPECIFIED = 0
        DRAFT = 2
        PENDING_APPROVAL = 3
        APPROVED = 4
        DISAPPROVED = 5
        PAUSED = 6
        CANCELED = 7
        DELETED = 8


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import (
    ad_review_center_ad_enums,
    exchange_syndication_product_enum,
)

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "AdReviewCenterAd",
    },
)


class AdReviewCenterAd(proto.Message):
    r"""Represents an ad that can be acted on or viewed in the Ad Review
    Center.
    [AdReviewCenterAd][google.ads.admanager.v1.AdReviewCenterAd].


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the AdReviewCenterAd.
            Format:
            ``networks/{network_code}/webProperties/{web_property_code}/adReviewCenterAds/{ad_review_center_ad_id}``
        ad_review_center_ad_id (str):
            Output only. ``AdReviewCenterAd`` ID.
        product_type (google.ads.admanager_v1.types.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct):
            Output only. Specifies the
            ExchangeSyndicationProduct for this
            AdReviewCenterAd.
        status (google.ads.admanager_v1.types.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus):
            The status of the AdReviewCenterAd.
        preview_url (str):
            Output only. The preview URL that can be
            embedded or accessed directly which will present
            the rendered contents of the ad. (This URL
            expires 72 hours after being retrieved.).

            This field is a member of `oneof`_ ``_preview_url``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ad_review_center_ad_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    product_type: exchange_syndication_product_enum.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct = proto.Field(
        proto.ENUM,
        number=3,
        enum=exchange_syndication_product_enum.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct,
    )
    status: ad_review_center_ad_enums.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus = proto.Field(
        proto.ENUM,
        number=4,
        enum=ad_review_center_ad_enums.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus,
    )
    preview_url: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import role_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Role",
    },
)


class Role(proto.Message):
    r"""The ``Role`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Role``. Format:
            ``networks/{network_code}/roles/{role_id}``
        role_id (int):
            Output only. ``Role`` ID.

            This field is a member of `oneof`_ ``_role_id``.
        display_name (str):
            Required. The display name of the ``Role``.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. The description of the ``Role``.

            This field is a member of `oneof`_ ``_description``.
        built_in (bool):
            Output only. Whether the ``Role`` is a built-in or custom
            user role.

            This field is a member of `oneof`_ ``_built_in``.
        status (google.ads.admanager_v1.types.RoleStatusEnum.RoleStatus):
            Output only. The status of the ``Role``.

            This field is a member of `oneof`_ ``_status``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    role_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    built_in: bool = proto.Field(
        proto.BOOL,
        number=5,
        optional=True,
    )
    status: role_enums.RoleStatusEnum.RoleStatus = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=role_enums.RoleStatusEnum.RoleStatus,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import time_unit_enum

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "FrequencyCap",
    },
)


class FrequencyCap(proto.Message):
    r"""Represents a Frequency Cap that can be applied to an entity.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        max_impressions (int):
            The maximum number of impressions for this
            frequency cap.

            This field is a member of `oneof`_ ``_max_impressions``.
        time_amount (int):
            The number of time units over which the
            frequency cap is effective.

            This field is a member of `oneof`_ ``_time_amount``.
        time_unit (google.ads.admanager_v1.types.TimeUnitEnum.TimeUnit):
            The units of time of this frequency cap.

            This field is a member of `oneof`_ ``_time_unit``.
    """

    max_impressions: int = proto.Field(
        proto.INT64,
        number=1,
        optional=True,
    )
    time_amount: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    time_unit: time_unit_enum.TimeUnitEnum.TimeUnit = proto.Field(
        proto.ENUM,
        number=3,
        optional=True,
        enum=time_unit_enum.TimeUnitEnum.TimeUnit,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import applied_label, company_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Company",
    },
)


class Company(proto.Message):
    r"""The ``Company`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Company``. Format:
            ``networks/{network_code}/companies/{company_id}``
        company_id (int):
            Output only. ``Company`` ID.

            This field is a member of `oneof`_ ``_company_id``.
        display_name (str):
            Required. The display name of the ``Company``.

            This value has a maximum length of 127 characters.

            This field is a member of `oneof`_ ``_display_name``.
        type_ (google.ads.admanager_v1.types.CompanyTypeEnum.CompanyType):
            Required. The type of the ``Company``.

            This field is a member of `oneof`_ ``_type``.
        address (str):
            Optional. The address for the ``Company``.

            This value has a maximum length of 1024 characters.

            This field is a member of `oneof`_ ``_address``.
        email (str):
            Optional. The email for the ``Company``.

            This value has a maximum length of 128 characters.

            This field is a member of `oneof`_ ``_email``.
        fax (str):
            Optional. The fax number for the ``Company``.

            This value has a maximum length of 63 characters.

            This field is a member of `oneof`_ ``_fax``.
        phone (str):
            Optional. The phone number for the ``Company``.

            This value has a maximum length of 63 characters.

            This field is a member of `oneof`_ ``_phone``.
        external_id (str):
            Optional. The external ID for the ``Company``.

            This value has a maximum length of 255 characters.

            This field is a member of `oneof`_ ``_external_id``.
        comment (str):
            Optional. Comments about the ``Company``.

            This value has a maximum length of 1024 characters.

            This field is a member of `oneof`_ ``_comment``.
        credit_status (google.ads.admanager_v1.types.CompanyCreditStatusEnum.CompanyCreditStatus):
            Optional. The credit status of the ``Company``.

            This attribute defaults to ``ACTIVE`` if basic settings are
            enabled and ``ON_HOLD`` if advance settings are enabled.

            This field is a member of `oneof`_ ``_credit_status``.
        applied_labels (MutableSequence[google.ads.admanager_v1.types.AppliedLabel]):
            Optional. The labels that are directly applied to the
            ``Company``.
        primary_contact (str):
            Optional. The resource names of primary Contact of the
            ``Company``. Format:
            "networks/{network_code}/contacts/{contact_id}".

            This field is a member of `oneof`_ ``_primary_contact``.
        applied_teams (MutableSequence[str]):
            Optional. The resource names of Teams that are directly
            associated with the ``Company``. Format:
            "networks/{network_code}/teams/{team_id}".
        third_party_company_id (int):
            Optional. The ID of the Google-recognized canonicalized form
            of the ``Company``.

            This field is a member of `oneof`_ ``_third_party_company_id``.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the ``Company`` was last modified.

            This field is a member of `oneof`_ ``_update_time``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    company_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    type_: company_enums.CompanyTypeEnum.CompanyType = proto.Field(
        proto.ENUM,
        number=4,
        optional=True,
        enum=company_enums.CompanyTypeEnum.CompanyType,
    )
    address: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    email: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    fax: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    phone: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    external_id: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    comment: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    credit_status: company_enums.CompanyCreditStatusEnum.CompanyCreditStatus = (
        proto.Field(
            proto.ENUM,
            number=11,
            optional=True,
            enum=company_enums.CompanyCreditStatusEnum.CompanyCreditStatus,
        )
    )
    applied_labels: MutableSequence[applied_label.AppliedLabel] = proto.RepeatedField(
        proto.MESSAGE,
        number=12,
        message=applied_label.AppliedLabel,
    )
    primary_contact: str = proto.Field(
        proto.STRING,
        number=13,
        optional=True,
    )
    applied_teams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=14,
    )
    third_party_company_id: int = proto.Field(
        proto.INT64,
        number=16,
        optional=True,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=15,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomFieldDataTypeEnum",
        "CustomFieldEntityTypeEnum",
        "CustomFieldStatusEnum",
        "CustomFieldVisibilityEnum",
    },
)


class CustomFieldDataTypeEnum(proto.Message):
    r"""Wrapper message for
    [CustomFieldDataType][google.ads.admanager.v1.CustomFieldDataTypeEnum.CustomFieldDataType]

    """

    class CustomFieldDataType(proto.Enum):
        r"""The data type for a CustomField.

        Values:
            CUSTOM_FIELD_DATA_TYPE_UNSPECIFIED (0):
                No value specified
            STRING (1):
                A string field

                The max length is 255 characters.
            NUMBER (2):
                A number field.
            TOGGLE (3):
                A "Yes" or "No" toggle field.
            DROP_DOWN (4):
                A drop-down field.
        """
        CUSTOM_FIELD_DATA_TYPE_UNSPECIFIED = 0
        STRING = 1
        NUMBER = 2
        TOGGLE = 3
        DROP_DOWN = 4


class CustomFieldEntityTypeEnum(proto.Message):
    r"""Wrapper message for
    [CustomFieldEntityType][google.ads.admanager.v1.CustomFieldEntityTypeEnum.CustomFieldEntityType]

    """

    class CustomFieldEntityType(proto.Enum):
        r"""The types of entities that a CustomField can be applied to.

        Values:
            CUSTOM_FIELD_ENTITY_TYPE_UNSPECIFIED (0):
                No value specified
            LINE_ITEM (1):
                The CustomField is applied to LineItems.
            ORDER (2):
                The CustomField is applied to Orders.
            CREATIVE (3):
                The CustomField is applied to Creatives.
            PROPOSAL (4):
                The CustomField is applied to Proposals.
            PROPOSAL_LINE_ITEM (5):
                The CustomField is applied to
                ProposalLineItems.
        """
        CUSTOM_FIELD_ENTITY_TYPE_UNSPECIFIED = 0
        LINE_ITEM = 1
        ORDER = 2
        CREATIVE = 3
        PROPOSAL = 4
        PROPOSAL_LINE_ITEM = 5


class CustomFieldStatusEnum(proto.Message):
    r"""Wrapper message for
    [CustomFieldStatus][google.ads.admanager.v1.CustomFieldStatusEnum.CustomFieldStatus]

    """

    class CustomFieldStatus(proto.Enum):
        r"""The status of the CustomField.

        Values:
            CUSTOM_FIELD_STATUS_UNSPECIFIED (0):
                No value specified
            ACTIVE (1):
                The CustomField is active.
            INACTIVE (2):
                The CustomField is inactive.
        """
        CUSTOM_FIELD_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


class CustomFieldVisibilityEnum(proto.Message):
    r"""Wrapper message for
    [CustomFieldVisibility][google.ads.admanager.v1.CustomFieldVisibilityEnum.CustomFieldVisibility]

    """

    class CustomFieldVisibility(proto.Enum):
        r"""The visibility level of a CustomField.

        Values:
            CUSTOM_FIELD_VISIBILITY_UNSPECIFIED (0):
                No value specified
            HIDDEN (1):
                The CustomField is not visible in the UI and
                only visible through the API.
            READ_ONLY (2):
                The CustomField is visible in the UI and only
                editable through the API.
            EDITABLE (3):
                The CustomField is visible and editable in
                both the API and UI.
        """
        CUSTOM_FIELD_VISIBILITY_UNSPECIFIED = 0
        HIDDEN = 1
        READ_ONLY = 2
        EDITABLE = 3


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "SizeTypeEnum",
    },
)


class SizeTypeEnum(proto.Message):
    r"""Wrapper message for
    [SizeType][google.ads.admanager.v1.SizeTypeEnum.SizeType].

    """

    class SizeType(proto.Enum):
        r"""The different Size types for an ad.

        Values:
            SIZE_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            PIXEL (1):
                Dimension based size, an actual height and
                width in pixels.
            ASPECT_RATIO (2):
                Size is expressed as a ratio. For example,
                4:1 could be met by a 100 x 25 sized image.
            INTERSTITIAL (3):
                Out-of-page (Interstitial) size that is not
                related to the slot it is served. This must be
                used with 1x1 size.
            IGNORED (4):
                Size is ignored. This must be used with 1x1
                size.
            NATIVE (5):
                Native size, which is a function of the how
                the client renders the creative. This must be
                used with 1x1 size.
            FLUID (6):
                Fluid size. Automatically sizes the ad by
                filling the width of the enclosing column and
                adjusting the height as appropriate. This must
                be used with 1x1 size.
            AUDIO (7):
                Audio size. Used with audio ads. This must be
                used with 1x1 size.
        """
        SIZE_TYPE_UNSPECIFIED = 0
        PIXEL = 1
        ASPECT_RATIO = 2
        INTERSTITIAL = 3
        IGNORED = 4
        NATIVE = 5
        FLUID = 6
        AUDIO = 7


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GeoTarget",
    },
)


class GeoTarget(proto.Message):
    r"""Represents a location in the world, for targeting.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``GeoTarget``. Format:
            ``networks/{network_code}/geoTargets/{geo_target_id}``
        display_name (str):
            Output only. The display name of the
            GeoTarget.

            This field is a member of `oneof`_ ``_display_name``.
        canonical_parent (str):
            Output only. The name of the direct parent that defines the
            canonical name of the geo target. For example, if the
            current geo target is "San Francisco", its canonical name
            would be "San Francisco, California, United States" thus the
            canonical_parent would be the name of California and the
            canonical_parent of California would be the name of United
            states Format:
            ``networks/{network_code}/geoTargets/{geo_target}``

            This field is a member of `oneof`_ ``_canonical_parent``.
        parent_names (MutableSequence[str]):
            Output only. All parents of the geo target
            ordered by ascending size.
        region_code (str):
            Output only. The Unicode CLDR region code of
            the geo target.

            This field is a member of `oneof`_ ``_region_code``.
        type_ (str):
            Output only. The location type (unlocalized)
            for this geographical entity.

            This field is a member of `oneof`_ ``_type``.
        targetable (bool):
            Output only. Whether the geo target is
            targetable.

            This field is a member of `oneof`_ ``_targetable``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    canonical_parent: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    parent_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    type_: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    targetable: bool = proto.Field(
        proto.BOOL,
        number=7,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "RoleStatusEnum",
    },
)


class RoleStatusEnum(proto.Message):
    r"""Wrapper message for
    [RoleStatus][google.ads.admanager.v1.RoleStatusEnum.RoleStatus]

    """

    class RoleStatus(proto.Enum):
        r"""The status of the role.

        Values:
            ROLE_STATUS_UNSPECIFIED (0):
                No value specified.
            ACTIVE (1):
                Role is active.
            INACTIVE (2):
                Role is inactive.
        """
        ROLE_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


__all__ = tuple(sorted(__protobuf__.manifest))
